/**
 * OW2 Util
 * Copyright (C) 2008
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IRepositoryManager.java 4392 2008-12-15 14:05:41Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.repository.api;

import java.util.Iterator;

import org.ow2.util.plan.bindings.exceptions.InvalidRepositoryException;
import org.ow2.util.plan.bindings.repository.Repository;

/**
 * Interface for the repository managers.
 * @author Mickaël LEDUQUE
 */
public interface IRepositoryManager extends Iterable<Repository>{

    /**
     * Add a repository to the managed ones.
     * @param repository the added repository
     * @throws RepositoryIdCollisionException when a repository with the same id is already in the manager.
     * @throws InvalidRepositoryException when the repository is not valid.
     */
    public void addRepository(final Repository repository)
            throws RepositoryIdCollisionException, InvalidRepositoryException;

    /**
     * Removes a repository from the managed ones.
     * @param repositoryId the id of the repository to be removed.
     */
    public void removeRepository(final Repository repository);

    /**
     * Returns the repository with the given id.
     * @param id the id of the wanted repository.
     * @return the repository with the matching id.
     */
    public Repository getRepositoryById(String id);

    /**
     * Returns an iterator over the repositories in the manager.
     * The iterator is sorted in order to get the local repositories first.
     * @return the iterator.
     */
    public Iterator<Repository> iterator();

    /**
     * Returns the number of repositories in the manager.
     * @return the number of repositories.
     */
    public Integer getRepositoryCount();
}
